@@ -2,6 +2,7 @@
 Protocol can be found at https://bkpmedia.s3.amazonaws.com/downloads/manuals/en-us/85xx_manual.pdf
 There is a section called Command details.
 """
+import datetime
 from dynamicmethod import dynamicmethod
 
 from pybk8500.field_types import Field, BytesField, StrField, \
@@ -29,7 +30,7 @@ __all__ = [
     'ReadTimerValueForLoadOn', 'SetTimerStateLoadOn', 'ReadTimerStateLoadOn', 'SetCommunicationAddress',
     'SetLocalControlState', 'SetRemoteSensingState', 'ReadRemoteSensingState', 'SelectTriggerSource',
     'ReadTriggerSource', 'TriggerElectronicLoad', 'SaveDCLoadSettings', 'RecallDCLoadSettings', 'SelectFunctionType',
-    'GetFunctionType', 'ReadInputVoltageCurrentPowerState', 'GetProductInfo', 'ReadBarCode'
+    'GetFunctionType', 'ReadInputVoltageCurrentPowerState', 'ReadInput', 'GetProductInfo', 'ReadBarCode'
     ]
 
 
@@ -103,6 +104,7 @@ class Message(bytearray):
         return msg_cls
 
     def __init__(self, raw=None, address=None, **kwargs):
+        self.timestamp = datetime.datetime.now()
         self.checksum_needs_updating = False
 
         byts = raw
@@ -1011,6 +1013,9 @@ class ReadInputVoltageCurrentPowerState(Message):
                                        })
 
 
+ReadInput = ReadInputVoltageCurrentPowerState
+
+
 @Parser.add_lookup
 class GetProductInfo(Message):
     """Get product's model, serial number, and firmware version"""
